Database access
===============

.. contents:: :local:


The database functionality has been moved to a separate, lightweight
Python package called ``km3db``::

    pip install km3db

km3pipe uses ``km3db`` internally to access the database.

Please check out its documentation at  https://km3py.pages.km3net.de/km3db
